@@ -73,3 +73,17 @@ parser.add_argument(
     + " specified as service:type (e.g. ec2:instance) to the generated policy, can be"
     + " repeated",
 )
+parser.add_argument(
+    "--no-wildcards",
+    action="store_true",
+    default=False,
+    help="Expand all wildcards",
+)
+parser.add_argument(
+    "--include-service-wide-actions",
+    "-S",
+    action="store_true",
+    default=False,
+    help="Include service-wide actions (ones not linked to a particular resource type)"
+    + " when using resource types",
+)
