@@ -6,6 +6,7 @@ from aws_policy_generator.auto_shortener import auto_shorten_policy
 from aws_policy_generator.yaml_generator import generate_from_yaml
 from aws_policy_generator._internal import argparser
 from aws_iam_utils.combiner import collapse_policy_statements
+from policyuniverse.expander_minimizer import expand_policy
 
 
 def main(args=None, return_policy=False):
@@ -25,6 +26,9 @@ def main(args=None, return_policy=False):
 
     policy = collapse_policy_statements(*policies)
 
+    if args_namespace.no_wildcards:
+        policy = expand_policy(policy)
+
     if args_namespace.auto_shorten:
         policy_str = auto_shorten_policy(
             policy,
